@@ -19,7 +19,11 @@ from jsonutils.exceptions import (
     JSONQueryException,
     JSONQueryMultipleValues,
 )
-from jsonutils.functions.decorators import catch_exceptions, return_value_on_exception
+from jsonutils.functions.decorators import (
+    catch_exceptions,
+    dummy,
+    return_value_on_exception,
+)
 from jsonutils.functions.parsers import (
     _parse_html_table,
     _parse_query,
@@ -784,6 +788,7 @@ class JSONCompose(JSONNode):
         include_parent_=None,
         throw_exceptions_=None,
         native_types_=None,
+        default_=dummy,
         **q,
     ):
 
@@ -806,6 +811,8 @@ class JSONCompose(JSONNode):
         )
 
         if not query.exists():
+            if default_ != dummy:
+                return default_
             if throw_exceptions_:
                 raise JSONQueryException("The query has not returned any result")
             else:
@@ -940,6 +947,50 @@ class JSONCompose(JSONNode):
                 )
         return queryset
 
+    def get_key(
+        self,
+        pattern,
+        recursive_=None,
+        include_parent_=None,
+        throw_exceptions_=None,
+        native_types_=None,
+        default_=dummy,
+        **q,
+    ):
+        # ---- DYNAMIC CONFIG ----
+        if recursive_ is None:
+            recursive_ = config.recursive_queries
+        if include_parent_ is None:
+            include_parent_ = config.include_parents
+        if throw_exceptions_ is None:
+            throw_exceptions_ = config.query_exceptions
+        if native_types_ is None:
+            native_types_ = config.native_types
+        # ------------------------
+        query = self.query_key(
+            pattern,
+            recursive_=recursive_,
+            include_parent_=include_parent_,
+            stop_at_match_=2,
+            native_types_=native_types_,
+            **q,
+        )
+
+        if not query.exists():
+            if default_ != dummy:
+                return default_
+            if throw_exceptions_:
+                raise JSONQueryException("The query has not returned any result")
+            else:
+                return None if native_types_ else JSONNull(None)
+        elif query.count() > 1:
+            if throw_exceptions_:
+                raise JSONQueryMultipleValues("More than one value returned by query")
+            else:
+                return query.first()
+        else:
+            return query.first()
+
     def _remove_annotations(self, recursive=True):
 
         if isinstance(self, JSONDict):
