@@ -367,6 +367,7 @@ class JsonTest(unittest.TestCase):
             test.get(timestamp="2021-05-01 08:00:00"),
             test.query(timestamp="2021-05-01 08:00:00").first(),
         )
+        self.assertEqual(test.get(fakeee=1, default_=5), 5)
 
         self.assertRaises(JSONQueryMultipleValues, lambda: test.get(pos__0=1))
 
@@ -1071,6 +1072,7 @@ class JsonTest(unittest.TestCase):
     def test_query_keys(self):
 
         test = JSONObject({"name": {"NAME": "Dan", "name": True}})
+        test2 = JSONObject(dict(A=0, B="012"))
 
         self.assertListEqual(
             test.query_key(js.I(".*na.*")).distinct(lambda x: x._key).keys(),
@@ -1112,6 +1114,21 @@ class JsonTest(unittest.TestCase):
             ),
             QuerySet([]),
         )
+        self.assertEqual(test2.query_key("*", type__="numeric"), [0, "012"])
+
+    def test_get_key(self):
+        test = self.test5
+
+        self.assertEqual(test.get_key(js.I("flo.*"), exact="1.1"), 1.1)
+        self.assertEqual(
+            test.get_key("Lis.*", __1=True), JSONList([None, True, False, 1])
+        )
+        self.assertEqual(
+            test.get_key(js.I("flo.*"), gte="1", throw_exceptions_=False), 1.1
+        )
+        self.assertEqual(test.get_key("FAKEKEY", default_=5), 5)
+        self.assertRaises(JSONQueryMultipleValues, lambda: test.get_key("Flo.*", gte=1))
+        self.assertRaises(JSONQueryException, lambda: test.get_key("FakeKey"))
 
     def test_traverse_json(self):
         # TODO what if a key has an explicit "
